@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
-/* Copyright © 2019-2024 Hans Petter Jansson. See COPYING for details. */
+/* Copyright © 2019-2025 Hans Petter Jansson. See COPYING for details. */
 
 /* If you're just going to use Smolscale in your project, you don't have to
  * worry about anything in here. The public API and documentation, such as
@@ -87,7 +87,12 @@ typedef unsigned int SmolBool;
 
 #define SMOL_ALIGNMENT 64
 
-#define SMOL_ASSIGN_ALIGNED_TO(x, t, n) (t) __builtin_assume_aligned ((x), (n))
+#ifdef SMOL_DISABLE_ASSUME_ALIGNED
+# define SMOL_ASSIGN_ALIGNED_TO(x, t, n) (t) (x)
+#else
+# define SMOL_ASSIGN_ALIGNED_TO(x, t, n) (t) __builtin_assume_aligned ((x), (n))
+#endif
+
 #define SMOL_ASSIGN_ALIGNED(x, t) SMOL_ASSIGN_ALIGNED_TO ((x), t, SMOL_ALIGNMENT)
 
 #define SMOL_ASSUME_ALIGNED_TO(x, t, n) (x) = SMOL_ASSIGN_ALIGNED_TO ((x), t, (n))
@@ -277,7 +282,7 @@ SmolRepackMeta;
      uint32_t n_pixels)                                                 \
     {                                                                   \
         uint##dest_limb_bits##_t *dest_row_max = dest_row + n_pixels * (dest_storage / dest_limb_bits); \
-        SMOL_ASSUME_ALIGNED_TO (src_row, uint##src_limb_bits##_t *, src_limb_bits / 8); \
+        SMOL_ASSUME_ALIGNED_TO (src_row, const uint##src_limb_bits##_t *, src_limb_bits / 8); \
         SMOL_ASSUME_ALIGNED_TO (dest_row, uint##dest_limb_bits##_t *, dest_limb_bits / 8);
 
 #define SMOL_REPACK_ROW_DEF_END }
@@ -288,7 +293,7 @@ typedef struct
     SmolInitFunc *init_v_func;
     SmolHFilterFunc *hfilter_funcs [SMOL_STORAGE_MAX] [SMOL_FILTER_MAX];
     SmolVFilterFunc *vfilter_funcs [SMOL_STORAGE_MAX] [SMOL_FILTER_MAX];
-    SmolCompositeOverColorFunc *composite_over_color_funcs [SMOL_STORAGE_MAX];
+    SmolCompositeOverColorFunc *composite_over_color_funcs [SMOL_STORAGE_MAX] [SMOL_GAMMA_MAX] [SMOL_ALPHA_MAX];
     SmolCompositeOverDestFunc *composite_over_dest_funcs [SMOL_STORAGE_MAX];
     SmolClearFunc *clear_funcs [SMOL_STORAGE_MAX];
     const SmolRepackMeta *repack_meta;
