@@ -200,7 +200,12 @@ ensure_raw_mode_enabled (ChafaTerm *term, struct termios *saved_termios,
     if (t.c_lflag != saved_termios->c_lflag)
     {
         *termios_changed = TRUE;
+
+        /* Note tcsetattr() can block on tty fds when we're in the background. */
         tcsetattr (chafa_stream_reader_get_fd (term->reader), TCSANOW, &t);
+
+        /* FIXME: Should probably call tcgetattr() here to ensure things went
+         * according to plan. */
     }
     else
     {
@@ -721,6 +726,8 @@ chafa_term_destroy (ChafaTerm *term)
 {
     g_return_if_fail (term != NULL);
 
+    chafa_term_flush (term);
+
     if (term->reader)
         chafa_stream_reader_unref (term->reader);
     if (term->writer)
@@ -738,6 +745,7 @@ chafa_term_destroy (ChafaTerm *term)
     win32_term_deinit (term);
 #endif
 
+    chafa_parser_destroy (term->parser);
     g_free (term);
 }
 
@@ -771,6 +779,17 @@ chafa_term_get_term_info (ChafaTerm *term)
     return term->term_info;
 }
 
+void
+chafa_term_set_term_info (ChafaTerm *term, ChafaTermInfo *term_info)
+{
+    if (term_info)
+        chafa_term_info_ref (term_info);
+    if (term->term_info)
+        chafa_term_info_unref (term->term_info);
+
+    term->term_info = term_info;
+}
+
 ChafaEvent *
 chafa_term_read_event (ChafaTerm *term, guint timeout_ms)
 {
